package org.nuiton.plugin;

/*
 * #%L
 * Helper Maven Plugin :: API
 * $Id: TestHelper.java 876 2012-11-11 08:14:19Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/maven-helper-plugin/tags/maven-helper-plugin-2.0/helper-maven-plugin-api/src/test/java/org/nuiton/plugin/TestHelper.java $
 * %%
 * Copyright (C) 2009 - 2012 Codelutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import org.apache.maven.plugin.Mojo;
import org.apache.maven.plugin.testing.AbstractMojoTestCase;
import org.codehaus.plexus.PlexusContainer;
import org.codehaus.plexus.PlexusTestCase;
import org.junit.Assert;
import org.junit.Ignore;

import java.io.File;

/**
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0.3
 */
public abstract class TestHelper extends PluginHelper {

    protected static boolean verbose;
    protected static File basedir;
    protected static DelegateMojoTestCase delegateMojoTest;

    /**
     * @return the basedir for all tests
     * @see PlexusTestCase#getBasedir()
     */
    public static File getBasedir() {
        if (basedir == null) {
            String path = PlexusTestCase.getBasedir();
            basedir = new File(path);
            if (verbose) {
                System.out.println("basedir = " + basedir.getAbsolutePath());
            }
        }
        return basedir;
    }

    public static void setBasedir(File basedir) {
        TestHelper.basedir = basedir;
    }

    public static boolean isVerbose() {
        return verbose;
    }

    public static void setVerbose(boolean verbose) {
        TestHelper.verbose = verbose;
    }

    public static File getTestDir(Class<?> type, String prefix) {
        File f = new File(getBasedir(), prefix);
        String rep = type.getName();
        String[] paths = rep.split("\\.");
        File testDir = getFile(f, paths);
        return testDir;
    }

    public static Mojo lookupMojo(String goalName, File pomFile) throws Exception {
        Mojo lookupMojo = getDelegateMojoTest().lookupMojo(goalName, pomFile);
        Assert.assertNotNull(lookupMojo);
        return lookupMojo;

    }

    public static DelegateMojoTestCase getDelegateMojoTest() throws Exception {
        if (delegateMojoTest == null) {
            delegateMojoTest = new DelegateMojoTestCase();
            TestHelper.delegateMojoTest.setUp();
        }
        return delegateMojoTest;
    }

    public static void setDelegateMojoTest(DelegateMojoTestCase delegateMojoTest) {
        TestHelper.delegateMojoTest = delegateMojoTest;
    }

    @Ignore
    public static class DelegateMojoTestCase extends AbstractMojoTestCase {

        @Override
        public Mojo lookupMojo(String goal, File pom) throws Exception {
            return super.lookupMojo(goal, pom);
        }

        @Override
        public void setUp() throws Exception {
            super.setUp();
        }

        @Override
        public void tearDown() throws Exception {
            super.tearDown();
        }

        @Override
        public PlexusContainer getContainer() {
            return super.getContainer();
        }
    }
}
